<?php

namespace Buyesrfolio\Transactions\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Buyesrfolio\Transactions\Http\Requests\PastTransactionRequest;
use Buyesrfolio\Transactions\Interfaces\PastTransactionRepositoryInterface;
use Buyesrfolio\Transactions\Models\PastTransaction;

/**
 * Resource controller class for past_transaction.
 */
class PastTransactionResourceController extends BaseController
{

    /**
     * Initialize past_transaction resource controller.
     *
     * @param type PastTransactionRepositoryInterface $past_transaction
     *
     * @return null
     */
    public function __construct(PastTransactionRepositoryInterface $past_transaction)
    {
        parent::__construct();
        $this->repository = $past_transaction;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Buyesrfolio\Transactions\Repositories\Criteria\PastTransactionResourceCriteria::class);
    }

    /**
     * Display a list of past_transaction.
     *
     * @return Response
     */
    public function index(PastTransactionRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Buyesrfolio\Transactions\Repositories\Presenter\PastTransactionPresenter::class)
                ->$function();
        }

        $past_transactions = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('transactions::past_transaction.names'))
            ->view('transactions::past_transaction.index', true)
            ->data(compact('past_transactions', 'view'))
            ->output();
    }

    /**
     * Display past_transaction.
     *
     * @param Request $request
     * @param Model   $past_transaction
     *
     * @return Response
     */
    public function show(PastTransactionRequest $request, PastTransaction $past_transaction)
    {

        if ($past_transaction->exists) {
            $view = 'transactions::past_transaction.show';
        } else {
            $view = 'transactions::past_transaction.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('transactions::past_transaction.name'))
            ->data(compact('past_transaction'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new past_transaction.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PastTransactionRequest $request)
    {

        $past_transaction = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('transactions::past_transaction.name')) 
            ->view('transactions::past_transaction.create', true) 
            ->data(compact('past_transaction'))
            ->output();
    }

    /**
     * Create new past_transaction.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PastTransactionRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $past_transaction                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('transactions::past_transaction.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('transactions/past_transaction/' . $past_transaction->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/transactions/past_transaction'))
                ->redirect();
        }

    }

    /**
     * Show past_transaction for editing.
     *
     * @param Request $request
     * @param Model   $past_transaction
     *
     * @return Response
     */
    public function edit(PastTransactionRequest $request, PastTransaction $past_transaction)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('transactions::past_transaction.name'))
            ->view('transactions::past_transaction.edit', true)
            ->data(compact('past_transaction'))
            ->output();
    }

    /**
     * Update the past_transaction.
     *
     * @param Request $request
     * @param Model   $past_transaction
     *
     * @return Response
     */
    public function update(PastTransactionRequest $request, PastTransaction $past_transaction)
    {
        try {
            $attributes = $request->all();

            $past_transaction->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('transactions::past_transaction.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('transactions/past_transaction/' . $past_transaction->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('transactions/past_transaction/' . $past_transaction->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the past_transaction.
     *
     * @param Model   $past_transaction
     *
     * @return Response
     */
    public function destroy(PastTransactionRequest $request, PastTransaction $past_transaction)
    {
        try {

            $past_transaction->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('transactions::past_transaction.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('transactions/past_transaction/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('transactions/past_transaction/' . $past_transaction->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple past_transaction.
     *
     * @param Model   $past_transaction
     *
     * @return Response
     */
    public function delete(PastTransactionRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('transactions::past_transaction.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('transactions/past_transaction'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/transactions/past_transaction'))
                ->redirect();
        }

    }

    /**
     * Restore deleted past_transactions.
     *
     * @param Model   $past_transaction
     *
     * @return Response
     */
    public function restore(PastTransactionRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('transactions::past_transaction.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/transactions/past_transaction'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/transactions/past_transaction/'))
                ->redirect();
        }

    }

}
