<?php

namespace Buyesrfolio\Transactions\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Buyesrfolio\Transactions\Http\Requests\TransactionFileRequest;
use Buyesrfolio\Transactions\Interfaces\TransactionFileRepositoryInterface;
use Buyesrfolio\Transactions\Models\TransactionFile;

/**
 * Resource controller class for transaction_file.
 */
class TransactionFileResourceController extends BaseController
{

    /**
     * Initialize transaction_file resource controller.
     *
     * @param type TransactionFileRepositoryInterface $transaction_file
     *
     * @return null
     */
    public function __construct(TransactionFileRepositoryInterface $transaction_file)
    {
        parent::__construct();
        $this->repository = $transaction_file;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Buyesrfolio\Transactions\Repositories\Criteria\TransactionFileResourceCriteria::class);
    }

    /**
     * Display a list of transaction_file.
     *
     * @return Response
     */
    public function index(TransactionFileRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Buyesrfolio\Transactions\Repositories\Presenter\TransactionFilePresenter::class)
                ->$function();
        }

        $transaction_files = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('transactions::transaction_file.names'))
            ->view('transactions::transaction_file.index', true)
            ->data(compact('transaction_files', 'view'))
            ->output();
    }

    /**
     * Display transaction_file.
     *
     * @param Request $request
     * @param Model   $transaction_file
     *
     * @return Response
     */
    public function show(TransactionFileRequest $request, TransactionFile $transaction_file)
    {

        if ($transaction_file->exists) {
            $view = 'transactions::transaction_file.show';
        } else {
            $view = 'transactions::transaction_file.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('transactions::transaction_file.name'))
            ->data(compact('transaction_file'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new transaction_file.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TransactionFileRequest $request)
    {

        $transaction_file = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('transactions::transaction_file.name')) 
            ->view('transactions::transaction_file.create', true) 
            ->data(compact('transaction_file'))
            ->output();
    }

    /**
     * Create new transaction_file.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TransactionFileRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $transaction_file                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('transactions::transaction_file.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('transactions/transaction_file/' . $transaction_file->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/transactions/transaction_file'))
                ->redirect();
        }

    }

    /**
     * Show transaction_file for editing.
     *
     * @param Request $request
     * @param Model   $transaction_file
     *
     * @return Response
     */
    public function edit(TransactionFileRequest $request, TransactionFile $transaction_file)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('transactions::transaction_file.name'))
            ->view('transactions::transaction_file.edit', true)
            ->data(compact('transaction_file'))
            ->output();
    }

    /**
     * Update the transaction_file.
     *
     * @param Request $request
     * @param Model   $transaction_file
     *
     * @return Response
     */
    public function update(TransactionFileRequest $request, TransactionFile $transaction_file)
    {
        try {
            $attributes = $request->all();

            $transaction_file->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('transactions::transaction_file.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('transactions/transaction_file/' . $transaction_file->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('transactions/transaction_file/' . $transaction_file->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the transaction_file.
     *
     * @param Model   $transaction_file
     *
     * @return Response
     */
    public function destroy(TransactionFileRequest $request, TransactionFile $transaction_file)
    {
        try {

            $transaction_file->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('transactions::transaction_file.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('transactions/transaction_file/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('transactions/transaction_file/' . $transaction_file->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple transaction_file.
     *
     * @param Model   $transaction_file
     *
     * @return Response
     */
    public function delete(TransactionFileRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('transactions::transaction_file.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('transactions/transaction_file'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/transactions/transaction_file'))
                ->redirect();
        }

    }

    /**
     * Restore deleted transaction_files.
     *
     * @param Model   $transaction_file
     *
     * @return Response
     */
    public function restore(TransactionFileRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('transactions::transaction_file.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/transactions/transaction_file'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/transactions/transaction_file/'))
                ->redirect();
        }

    }

}
